@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Bencher::Scenario;
 
-our $DATE = '2016-03-15'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2016-05-23'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -141,6 +141,14 @@ sub munge_files {
 
     local @INC = ("lib", @INC);
 
+    # gather dist modules
+    my %distmodules;
+    for my $file (@{ $self->found_files }) {
+        next unless $file->name =~ m!\Alib/(.+)\.pm\z!;
+        my $mod = $1; $mod =~ s!/!::!g;
+        $distmodules{$mod}++;
+    }
+
     my %seen_mods;
     for my $file (@{ $self->found_files }) {
         next unless $file->name =~ m!\Alib/(Bencher/Scenario/.+)\.pm\z!;
@@ -151,6 +159,7 @@ sub munge_files {
         my $scenario = Bencher::Backend::parse_scenario(scenario=>${"$pkg\::scenario"});
         my @modules = Bencher::Backend::_get_participant_modules($scenario);
         for my $mod (@modules) {
+            next if $distmodules{$mod};
             next if $seen_mods{$mod}++;
             my $ver = $scenario->{modules}{$mod}{version} // 0;
             $self->log_debug(
@@ -193,7 +202,7 @@ Dist::Zilla::Plugin::Bencher::Scenario - Plugin to use when building Bencher::Sc
 
 =head1 VERSION
 
-This document describes version 0.11 of Dist::Zilla::Plugin::Bencher::Scenario (from Perl distribution Dist-Zilla-Plugin-Bencher-Scenario), released on 2016-03-15.
+This document describes version 0.12 of Dist::Zilla::Plugin::Bencher::Scenario (from Perl distribution Dist-Zilla-Plugin-Bencher-Scenario), released on 2016-05-23.
 
 =head1 SYNOPSIS
 
